@@ -7,18 +7,22 @@ module Capybara
   class DriverNotFoundError < CapybaraError; end
   class FrozenInTime < CapybaraError; end
   class ElementNotFound < CapybaraError; end
+  class ModalNotFound < CapybaraError; end
   class Ambiguous < ElementNotFound; end
   class ExpectationNotMet < ElementNotFound; end
   class FileNotFound < CapybaraError; end
   class UnselectNotAllowed < CapybaraError; end
   class NotSupportedByDriverError < CapybaraError; end
   class InfiniteRedirectError < CapybaraError; end
+  class ScopeError < CapybaraError; end
+  class WindowError < CapybaraError; end
+  class ReadOnlyElementError < CapybaraError; end
 
   class << self
     attr_accessor :asset_host, :app_host, :run_server, :default_host, :always_include_port
     attr_accessor :server_port, :exact, :match, :exact_options, :visible_text_only
-    attr_accessor :default_selector, :default_wait_time, :ignore_hidden_elements
-    attr_accessor :save_and_open_page_path, :automatic_reload, :raise_server_errors
+    attr_accessor :default_selector, :default_max_wait_time, :ignore_hidden_elements
+    attr_accessor :save_and_open_page_path, :wait_on_first_by_default, :automatic_reload, :raise_server_errors, :server_errors
     attr_writer :default_driver, :current_driver, :javascript_driver, :session_name, :server_host
     attr_accessor :app
 
@@ -33,22 +37,24 @@ module Capybara
     #
     # === Configurable options
     #
-    # [app_host = String]                 The default host to use when giving a relative URL to visit
-    # [always_include_port = Boolean]     Whether the Rack server's port should automatically be inserted into every visited URL (Default: false)
-    # [asset_host = String]               Where dynamic assets are hosted - will be prepended to relative asset locations if present (Default: nil)
-    # [run_server = Boolean]              Whether to start a Rack server for the given Rack app (Default: true)
-    # [default_selector = :css/:xpath]    Methods which take a selector use the given type by default (Default: CSS)
-    # [default_wait_time = Integer]       The number of seconds to wait for asynchronous processes to finish (Default: 2)
-    # [ignore_hidden_elements = Boolean]  Whether to ignore hidden elements on the page (Default: false)
-    # [automatic_reload = Boolean]        Whether to automatically reload elements as Capybara is waiting (Default: true)
-    # [save_and_open_page_path = String]  Where to put pages saved through save_and_open_page (Default: Dir.pwd)
-    #
+    # [app_host = String]                 The default host to use when giving a relative URL to visit  
+    # [always_include_port = Boolean]     Whether the Rack server's port should automatically be inserted into every visited URL (Default: false)  
+    # [asset_host = String]               Where dynamic assets are hosted - will be prepended to relative asset locations if present (Default: nil)  
+    # [run_server = Boolean]              Whether to start a Rack server for the given Rack app (Default: true)  
+    # [raise_server_errors = Boolean]     Should errors raised in the server be raised in the tests? (Default: true)  
+    # [server_errors = Array\<Class\>]    Error classes that should be raised in the tests if they are raised in the server and Capybara.raise_server_errors is true (Default: [StandardError])  
+    # [default_selector = :css/:xpath]    Methods which take a selector use the given type by default (Default: :css)  
+    # [default_max_wait_time = Numeric]   The maximum number of seconds to wait for asynchronous processes to finish (Default: 2)  
+    # [ignore_hidden_elements = Boolean]  Whether to ignore hidden elements on the page (Default: true)  
+    # [automatic_reload = Boolean]        Whether to automatically reload elements as Capybara is waiting (Default: true)  
+    # [save_and_open_page_path = String]  Where to put pages saved through save_and_open_page (Default: Dir.pwd)  
+    # [wait_on_first_by_default = Boolean]   Whether Node#first defaults to Capybara waiting behavior for at least 1 element to match (Default: false) 
     # === DSL Options
     #
     # when using capybara/dsl, the following options are also available:
     #
-    # [default_driver = Symbol]           The name of the driver to use by default. (Default: :rack_test)
-    # [javascript_driver = Symbol]        The name of a driver to use for JavaScript enabled tests. (Default: :selenium)
+    # [default_driver = Symbol]           The name of the driver to use by default. (Default: :rack_test)  
+    # [javascript_driver = Symbol]        The name of a driver to use for JavaScript enabled tests. (Default: :selenium)  
     #
     def configure
       yield self
@@ -59,12 +65,12 @@ module Capybara
     # Register a new driver for Capybara.
     #
     #     Capybara.register_driver :rack_test do |app|
-    #       Capybara::Driver::RackTest.new(app)
+    #       Capybara::RackTest::Driver.new(app)
     #     end
     #
     # @param [Symbol] name                    The name of the new driver
     # @yield [app]                            This block takes a rack app and returns a Capybara driver
-    # @yieldparam [<Rack>] app                The rack application that this driver runs agains. May be nil.
+    # @yieldparam [<Rack>] app                The rack application that this driver runs against. May be nil.
     # @yieldreturn [Capybara::Driver::Base]   A Capybara driver instance
     #
     def register_driver(name, &block)
@@ -86,7 +92,7 @@ module Capybara
     #     find(:row, 3)
     #     page.find('table#myTable').find(:row, 3).text
     #     page.find('table#myTable').has_selector?(:row, 3)
-    #     within(:row, 3) { page.should have_content('$100.000') }
+    #     within(:row, 3) { expect(page).to have_content('$100.000') }
     #
     # Here is another example:
     #
@@ -118,7 +124,7 @@ module Capybara
     #
     # By default, Capybara will try to run webrick.
     #
-    # @yield [app, port]                      This block recieves a rack app and port and should run a Rack handler
+    # @yield [app, port]                      This block receives a rack app and port and should run a Rack handler
     #
     def server(&block)
       if block_given?
@@ -131,9 +137,9 @@ module Capybara
     ##
     #
     # Wraps the given string, which should contain an HTML document or fragment
-    # in a {Capybara::Node::Simple} which exposes all {Capybara::Node::Matchers} and
-    # {Capybara::Node::Finders}. This allows you to query any string containing
-    # HTML in the exact same way you would query the current document in a Capybara
+    # in a {Capybara::Node::Simple} which exposes all {Capybara::Node::Matchers},
+    # {Capybara::Node::Finders} and {Capybara::Node::DocumentMatchers}. This allows you to query
+    # any string containing HTML in the exact same way you would query the current document in a Capybara
     # session. For example:
     #
     #     node = Capybara.string <<-HTML
@@ -145,8 +151,8 @@ module Capybara
     #
     #     node.find('#projects').text # => 'Projects'
     #     node.has_selector?('li#home', :text => 'Home')
-    #     node.has_selector?(:projects)
-    #     node.find('ul').find('li').text # => 'Home'
+    #     node.has_selector?('#projects')
+    #     node.find('ul').find('li:first-child').text # => 'Home'
     #
     # @param [String] html              An html fragment or document
     # @return [Capybara::Node::Simple]   A node which has Capybara's finders and matchers
@@ -227,11 +233,11 @@ module Capybara
     # Yield a block using a specific wait time
     #
     def using_wait_time(seconds)
-      previous_wait_time = Capybara.default_wait_time
-      Capybara.default_wait_time = seconds
+      previous_wait_time = Capybara.default_max_wait_time
+      Capybara.default_max_wait_time = seconds
       yield
     ensure
-      Capybara.default_wait_time = previous_wait_time
+      Capybara.default_max_wait_time = previous_wait_time
     end
 
     ##
@@ -269,10 +275,11 @@ module Capybara
     # Yield a block using a specific session name.
     #
     def using_session(name)
+      previous_session_name = self.session_name
       self.session_name = name
       yield
     ensure
-      self.session_name = :default
+      self.session_name = previous_session_name
     end
 
     ##
@@ -289,14 +296,28 @@ module Capybara
         end
       end
     end
+    
+    # @deprecated Use default_max_wait_time instead
+    def default_wait_time
+      deprecate('default_wait_time', 'default_max_wait_time', true)
+      default_max_wait_time
+    end
+    
+    # @deprecated Use default_max_wait_time= instead
+    def default_wait_time=(t)
+      deprecate('default_wait_time=', 'default_max_wait_time=')
+      self.default_max_wait_time = t
+    end
 
     def included(base)
       base.send(:include, Capybara::DSL)
       warn "`include Capybara` is deprecated. Please use `include Capybara::DSL` instead."
     end
 
-    def deprecate(method, alternate_method)
-      warn "DEPRECATED: ##{method} is deprecated, please use ##{alternate_method} instead"
+    def deprecate(method, alternate_method, once=false)
+      @deprecation_notified ||= {}
+      warn "DEPRECATED: ##{method} is deprecated, please use ##{alternate_method} instead" unless once and @deprecation_notified[method]
+      @deprecation_notified[method]=true
     end
 
   private
@@ -308,6 +329,7 @@ module Capybara
 
   self.default_driver = nil
   self.current_driver = nil
+  self.server_host = nil
 
   module Driver; end
   module RackTest; end
@@ -316,15 +338,22 @@ module Capybara
   require 'capybara/helpers'
   require 'capybara/session'
   require 'capybara/dsl'
+  require 'capybara/window'
   require 'capybara/server'
   require 'capybara/selector'
-  require 'capybara/query'
   require 'capybara/result'
   require 'capybara/version'
 
+  require 'capybara/queries/base_query'
+  require 'capybara/query'
+  require 'capybara/queries/text_query'
+  require 'capybara/queries/title_query'
+  require 'capybara/queries/current_path_query'
+  
   require 'capybara/node/finders'
   require 'capybara/node/matchers'
   require 'capybara/node/actions'
+  require 'capybara/node/document_matchers'
   require 'capybara/node/simple'
   require 'capybara/node/base'
   require 'capybara/node/element'
@@ -348,14 +377,16 @@ Capybara.configure do |config|
   config.run_server = true
   config.server {|app, port| Capybara.run_default_server(app, port)}
   config.default_selector = :css
-  config.default_wait_time = 2
+  config.default_max_wait_time = 2
   config.ignore_hidden_elements = true
   config.default_host = "http://www.example.com"
   config.automatic_reload = true
   config.match = :smart
   config.exact = false
   config.raise_server_errors = true
+  config.server_errors = [StandardError]
   config.visible_text_only = false
+  config.wait_on_first_by_default = false
 end
 
 Capybara.register_driver :rack_test do |app|
