@@ -16,12 +16,11 @@ module Capybara
 
       ##
       #
-      # Finds a link by id or text and clicks it. Also looks at image
+      # Finds a link by id, text or title and clicks it. Also looks at image
       # alt text inside the link.
       #
-      # @param [String] locator      Text or id of link
-      # @param options
-      # @option options [String] :href    The value the href attribute must be
+      # @param [String] locator         text, id, title or nested image's alt attribute
+      # @param options                  See {Capybara::Node::Finders#find_link}
       #
       def click_link(locator, options={})
         find(:link, locator, options).click
@@ -29,10 +28,13 @@ module Capybara
 
       ##
       #
-      # Finds a button by id, text or value and clicks it.
-      #
-      # @param [String] locator      Text, id or value of button
+      # Finds a button on the page and clicks it.
+      # This can be any \<input> element of type submit, reset, image, button or it can be a
+      # \<button> element. All buttons can be found by their id, value, or title. \<button> elements can also be found
+      # by their text content, and image \<input> elements by their alt attribute
       #
+      # @param [String] locator      Which button to find
+      # @param options     See {Capybara::Node::Finders#find_button}
       def click_button(locator, options={})
         find(:button, locator, options).click
       end
@@ -45,12 +47,15 @@ module Capybara
       #     page.fill_in 'Name', :with => 'Bob'
       #
       # @param [String] locator                 Which field to fill in
-      # @param [Hash{:with => String}] options  The value to fill in
+      # @param [Hash] options
+      # @option options [String] :with     The value to fill in - required
+      # @option options [Hash] :fill_options Driver specific options regarding how to fill fields
       #
       def fill_in(locator, options={})
         raise "Must pass a hash containing 'with'" if not options.is_a?(Hash) or not options.has_key?(:with)
         with = options.delete(:with)
-        find(:fillable_field, locator, options).set(with)
+        fill_options = options.delete(:fill_options)
+        find(:fillable_field, locator, options).set(with, fill_options)
       end
 
       ##
@@ -94,14 +99,17 @@ module Capybara
 
       ##
       #
-      # Find a select box on the page and select a particular option from it. If the select
-      # box is a multiple select, +select+ can be called multiple times to select more than
-      # one option. The select box can be found via its name, id or label text.
+      # If `:from` option is present, `select` finds a select box on the page
+      # and selects a particular option from it.
+      # Otherwise it finds an option inside current scope and selects it.
+      # If the select box is a multiple select, +select+ can be called multiple times to select more than
+      # one option.
+      # The select box can be found via its name, id or label text. The option can be found by its text.
       #
       #     page.select 'March', :from => 'Month'
       #
       # @param [String] value                   Which option to select
-      # @param [Hash{:from => String}] options  The id, name or label of the select box
+      # @option options [String] :from  The id, name or label of the select box
       #
       def select(value, options={})
         if options.has_key?(:from)
