@@ -14,6 +14,7 @@ module Capybara
     class Simple
       include Capybara::Node::Finders
       include Capybara::Node::Matchers
+      include Capybara::Node::DocumentMatchers
 
       attr_reader :native
 
@@ -94,10 +95,17 @@ module Capybara
       # Whether or not the element is visible. Does not support CSS, so
       # the result may be inaccurate.
       #
+      # @param  [Boolean] check_ancestors  Whether to inherit visibility from ancestors
       # @return [Boolean]     Whether the element is visible
       #
-      def visible?
-        native.xpath("./ancestor-or-self::*[contains(@style, 'display:none') or contains(@style, 'display: none') or @hidden or name()='script' or name()='head']").size == 0
+      def visible?(check_ancestors = true)
+        if check_ancestors
+          #check size because oldest supported nokogiri doesnt support xpath boolean() function
+          native.xpath("./ancestor-or-self::*[contains(@style, 'display:none') or contains(@style, 'display: none') or @hidden or name()='script' or name()='head']").size() == 0
+        else
+          #no need for an xpath if only checking the current element
+          !(native.has_attribute?('hidden') || (native[:style] =~ /display:\s?none/) || %w(script head).include?(tag_name))
+        end
       end
 
       ##
@@ -138,28 +146,26 @@ module Capybara
       end
 
       def title
-        native.xpath("//title").first.text
-      end
-
-      def has_title?(content)
-        title.match(Capybara::Helpers.to_regexp(content))
-      end
-
-      def has_no_title?(content)
-        not has_title?(content)
-      end
-
-    private
-
-      def resolve_query(query, exact=nil)
-        elements = if query.selector.format == :css
-          native.css(query.css)
+        if native.respond_to? :title
+          native.title
         else
-          native.xpath(query.xpath(exact))
-        end.map do |node|
-          self.class.new(node)
+          #old versions of nokogiri don't have #title - remove in 3.0
+          native.xpath('/html/head/title | /html/title').first.text
         end
-        Capybara::Result.new(elements, query)
+      end
+
+      def inspect
+        %(#<Capybara::Node::Simple tag="#{tag_name}" path="#{path}">)
+      end
+
+      # @api private
+      def find_css(css)
+        native.css(css)
+      end
+
+      # @api private
+      def find_xpath(xpath)
+        native.xpath(xpath)
       end
     end
   end
