@@ -27,11 +27,16 @@ class Capybara::RackTest::Node < Capybara::Driver::Node
     elsif input_field?
       set_input(value)
     elsif textarea?
-      native.content = value.to_s unless self[:readonly]
+      if self[:readonly]
+        warn "Attempt to set readonly element with value: #{value} \n * This will raise an exception in a future version of Capybara"
+      else
+        native.content = value.to_s
+      end
     end
   end
 
   def select_option
+    return if disabled?
     if select_node['multiple'] != 'multiple'
       select_node.find_xpath(".//option[@selected]").each { |node| node.native.remove_attribute("selected") }
     end
@@ -46,7 +51,7 @@ class Capybara::RackTest::Node < Capybara::Driver::Node
   end
 
   def click
-    if tag_name == 'a'
+    if tag_name == 'a' && !self[:href].nil?
       method = self["data-method"] if driver.options[:respect_data_method]
       method ||= :get
       driver.follow(method, self[:href].to_s)
@@ -99,14 +104,14 @@ class Capybara::RackTest::Node < Capybara::Driver::Node
 
 protected
 
-  def unnormalized_text
-    if !visible?
+  def unnormalized_text(check_ancestor_visibility = true)
+    if !string_node.visible?(check_ancestor_visibility)
       ''
     elsif native.text?
       native.text
     elsif native.element?
       native.children.map do |child|
-        Capybara::RackTest::Node.new(driver, child).unnormalized_text
+        Capybara::RackTest::Node.new(driver, child).unnormalized_text(false)
       end.join
     else
       ''
@@ -165,7 +170,11 @@ private
       end
       native.remove
     else
-      native['value'] = value.to_s unless self[:readonly]
+      if self[:readonly]
+        warn "Attempt to set readonly element with value: #{value} \n *This will raise an exception in a future version of Capybara"
+      else
+        native['value'] = value.to_s
+      end
     end
   end
 
