@@ -23,7 +23,7 @@ class Capybara::Selenium::Node < Capybara::Driver::Node
     end
   end
 
-  def set(value)
+  def set(value, fill_options={})
     tag_name = self.tag_name
     type = self[:type]
     if (Array === value) && !self[:multiple]
@@ -37,12 +37,22 @@ class Capybara::Selenium::Node < Capybara::Driver::Node
       path_names = value.to_s.empty? ? [] : value
       native.send_keys(*path_names)
     elsif tag_name == 'textarea' or tag_name == 'input'
-      if value.to_s.empty?
+      if self[:readonly]
+        warn "Attempt to set readonly element with value: #{value} \n *This will raise an exception in a future version of Capybara"
+      elsif value.to_s.empty?
         native.clear
       else
-        #script can change a readonly element which user input cannot, so dont execute if readonly
-        driver.browser.execute_script "arguments[0].value = ''", native unless self[:readonly]
-        native.send_keys(value.to_s)
+        if fill_options[:clear] == :backspace
+          # Clear field by sending the correct number of backspace keys.
+          backspaces = [:backspace] * self.value.to_s.length
+          native.send_keys(*(backspaces + [value.to_s]))
+        else
+          # Clear field by JavaScript assignment of the value property.
+          # Script can change a readonly element which user input cannot, so
+          # don't execute if readonly.
+          driver.browser.execute_script "arguments[0].value = ''", native
+          native.send_keys(value.to_s)
+        end
       end
     elsif native.attribute('isContentEditable')
       #ensure we are focused on the element
@@ -71,6 +81,18 @@ class Capybara::Selenium::Node < Capybara::Driver::Node
     native.click
   end
 
+  def right_click
+    driver.browser.action.context_click(native).perform
+  end
+
+  def double_click
+    driver.browser.action.double_click(native).perform
+  end
+
+  def send_keys(*args)
+    native.send_keys(*args)
+  end
+
   def hover
     driver.browser.action.move_to(native).perform
   end
@@ -111,6 +133,30 @@ class Capybara::Selenium::Node < Capybara::Driver::Node
     native == other.native
   end
 
+  def path
+    path = find_xpath('ancestor::*').reverse
+    path.unshift self
+
+    result = []
+    while node = path.shift
+      parent = path.first
+
+      if parent
+        siblings = parent.find_xpath(node.tag_name)
+        if siblings.size == 1
+          result.unshift node.tag_name
+        else
+          index = siblings.index(node)
+          result.unshift "#{node.tag_name}[#{index+1}]"
+        end
+      else
+        result.unshift node.tag_name
+      end
+    end
+
+    '/' + result.join('/')
+  end
+
 private
 
   # a reference to the select node if this is an option node
