@@ -10,19 +10,19 @@ Capybara::SpecHelper.spec "#attach_file" do
     it "should set a file path by id" do
       @session.attach_file "form_image", __FILE__
       @session.click_button('awesome')
-      extract_results(@session)['image'].should == File.basename(__FILE__)
+      expect(extract_results(@session)['image']).to eq(File.basename(__FILE__))
     end
 
     it "should set a file path by label" do
       @session.attach_file "Image", __FILE__
       @session.click_button('awesome')
-      extract_results(@session)['image'].should == File.basename(__FILE__)
+      expect(extract_results(@session)['image']).to eq(File.basename(__FILE__))
     end
 
     it "casts to string" do
       @session.attach_file :"form_image", __FILE__
       @session.click_button('awesome')
-      extract_results(@session)['image'].should == File.basename(__FILE__)
+      expect(extract_results(@session)['image']).to eq(File.basename(__FILE__))
     end
   end
 
@@ -30,51 +30,51 @@ Capybara::SpecHelper.spec "#attach_file" do
     it "should set a file path by id" do
       @session.attach_file "form_document", @test_file_path
       @session.click_button('Upload Single')
-      @session.should have_content(File.read(@test_file_path))
+      expect(@session).to have_content(File.read(@test_file_path))
     end
 
     it "should set a file path by label" do
       @session.attach_file "Single Document", @test_file_path
       @session.click_button('Upload Single')
-      @session.should have_content(File.read(@test_file_path))
+      expect(@session).to have_content(File.read(@test_file_path))
     end
 
     it "should not break if no file is submitted" do
       @session.click_button('Upload Single')
-      @session.should have_content('No file uploaded')
+      expect(@session).to have_content('No file uploaded')
     end
 
     it "should send content type text/plain when uploading a text file" do
       @session.attach_file "Single Document", @test_file_path
       @session.click_button 'Upload Single'
-      @session.should have_content('text/plain')
+      expect(@session).to have_content('text/plain')
     end
 
     it "should send content type image/jpeg when uploading an image" do
       @session.attach_file "Single Document", @test_jpg_file_path
       @session.click_button 'Upload Single'
-      @session.should have_content('image/jpeg')
+      expect(@session).to have_content('image/jpeg')
     end
 
     it "should not break when using HTML5 multiple file input" do
       @session.attach_file "Multiple Documents", @test_file_path
       @session.click_button('Upload Multiple')
-      @session.body.should include("1 | ")#number of files
-      @session.should have_content(File.read(@test_file_path))
+      expect(@session).to have_content(File.read(@test_file_path))
+      expect(@session.body).to include("1 | ")#number of files
     end
 
     it  "should not break when using HTML5 multiple file input uploading multiple files" do
       pending "Selenium is buggy on this, see http://code.google.com/p/selenium/issues/detail?id=2239" if @session.respond_to?(:mode) && @session.mode.to_s =~ /^selenium/
       @session.attach_file "Multiple Documents", [@test_file_path, @another_test_file_path]
       @session.click_button('Upload Multiple')
-      @session.body.should include("2 | ")#number of files
-      @session.body.should include(File.read(@test_file_path))
-      @session.body.should include(File.read(@another_test_file_path))
+      expect(@session.body).to include("2 | ")#number of files
+      expect(@session.body).to include(File.read(@test_file_path))
+      expect(@session.body).to include(File.read(@another_test_file_path))
     end
 
     it "should not send anything when attaching no files to a multiple upload field" do
       @session.click_button('Upload Empty Multiple')
-      @session.body.should include("Successfully ignored empty file field")
+      expect(@session).to have_content("Successfully ignored empty file field")
     end
   end
 
@@ -97,7 +97,7 @@ Capybara::SpecHelper.spec "#attach_file" do
     it "should set a file path by partial label when false" do
       @session.attach_file "Imag", __FILE__, :exact => false
       @session.click_button('awesome')
-      extract_results(@session)['image'].should == File.basename(__FILE__)
+      expect(extract_results(@session)['image']).to eq(File.basename(__FILE__))
     end
 
     it "not allow partial matches when true" do
