@@ -6,101 +6,101 @@ Capybara::SpecHelper.spec "#fill_in" do
   it "should fill in a text field by id" do
     @session.fill_in('form_first_name', :with => 'Harry')
     @session.click_button('awesome')
-    extract_results(@session)['first_name'].should == 'Harry'
+    expect(extract_results(@session)['first_name']).to eq('Harry')
   end
 
   it "should fill in a text field by name" do
     @session.fill_in('form[last_name]', :with => 'Green')
     @session.click_button('awesome')
-    extract_results(@session)['last_name'].should == 'Green'
+    expect(extract_results(@session)['last_name']).to eq('Green')
   end
 
   it "should fill in a text field by label without for" do
     @session.fill_in('First Name', :with => 'Harry')
     @session.click_button('awesome')
-    extract_results(@session)['first_name'].should == 'Harry'
+    expect(extract_results(@session)['first_name']).to eq('Harry')
   end
 
   it "should fill in a url field by label without for" do
     @session.fill_in('Html5 Url', :with => 'http://www.avenueq.com')
     @session.click_button('html5_submit')
-    extract_results(@session)['html5_url'].should == 'http://www.avenueq.com'
+    expect(extract_results(@session)['html5_url']).to eq('http://www.avenueq.com')
   end
 
   it "should fill in a textarea by id" do
     @session.fill_in('form_description', :with => 'Texty text')
     @session.click_button('awesome')
-    extract_results(@session)['description'].should == 'Texty text'
+    expect(extract_results(@session)['description']).to eq('Texty text')
   end
 
   it "should fill in a textarea by label" do
     @session.fill_in('Description', :with => 'Texty text')
     @session.click_button('awesome')
-    extract_results(@session)['description'].should == 'Texty text'
+    expect(extract_results(@session)['description']).to eq('Texty text')
   end
 
   it "should fill in a textarea by name" do
     @session.fill_in('form[description]', :with => 'Texty text')
     @session.click_button('awesome')
-    extract_results(@session)['description'].should == 'Texty text'
+    expect(extract_results(@session)['description']).to eq('Texty text')
   end
 
   it "should fill in a password field by id" do
     @session.fill_in('form_password', :with => 'supasikrit')
     @session.click_button('awesome')
-    extract_results(@session)['password'].should == 'supasikrit'
+    expect(extract_results(@session)['password']).to eq('supasikrit')
   end
 
   it "should handle HTML in a textarea" do
     @session.fill_in('form_description', :with => 'is <strong>very</strong> secret!')
     @session.click_button('awesome')
-    extract_results(@session)['description'].should == 'is <strong>very</strong> secret!'
+    expect(extract_results(@session)['description']).to eq('is <strong>very</strong> secret!')
   end
 
   it "should handle newlines in a textarea" do
     @session.fill_in('form_description', :with => "\nSome text\n")
     @session.click_button('awesome')
-    extract_results(@session)['description'].should == "\r\nSome text\r\n"
+    expect(extract_results(@session)['description']).to eq("\r\nSome text\r\n")
   end
 
   it "should fill in a field with a custom type" do
     @session.fill_in('Schmooo', :with => 'Schmooo is the game')
     @session.click_button('awesome')
-    extract_results(@session)['schmooo'].should == 'Schmooo is the game'
+    expect(extract_results(@session)['schmooo']).to eq('Schmooo is the game')
   end
 
   it "should fill in a field without a type" do
     @session.fill_in('Phone', :with => '+1 555 7022')
     @session.click_button('awesome')
-    extract_results(@session)['phone'].should == '+1 555 7022'
+    expect(extract_results(@session)['phone']).to eq('+1 555 7022')
   end
 
   it "should fill in a text field respecting its maxlength attribute" do
     @session.fill_in('Zipcode', :with => '52071350')
     @session.click_button('awesome')
-    extract_results(@session)['zipcode'].should == '52071'
+    expect(extract_results(@session)['zipcode']).to eq('52071')
   end
 
   it "should fill in a password field by name" do
     @session.fill_in('form[password]', :with => 'supasikrit')
     @session.click_button('awesome')
-    extract_results(@session)['password'].should == 'supasikrit'
+    expect(extract_results(@session)['password']).to eq('supasikrit')
   end
 
   it "should fill in a password field by label" do
     @session.fill_in('Password', :with => 'supasikrit')
     @session.click_button('awesome')
-    extract_results(@session)['password'].should == 'supasikrit'
+    expect(extract_results(@session)['password']).to eq('supasikrit')
   end
 
   it "should fill in a password field by name" do
     @session.fill_in('form[password]', :with => 'supasikrit')
     @session.click_button('awesome')
-    extract_results(@session)['password'].should == 'supasikrit'
+    expect(extract_results(@session)['password']).to eq('supasikrit')
   end
 
   it "should throw an exception if a hash containing 'with' is not provided" do
-    lambda{@session.fill_in 'Name', 'ignu'}.should raise_error
+    expect {@session.fill_in 'Name', 'ignu'}.to raise_error(RuntimeError, /with/)
   end
 
   it "should wait for asynchronous load", :requires => [:js] do
@@ -112,13 +112,13 @@ Capybara::SpecHelper.spec "#fill_in" do
   it "casts to string" do
     @session.fill_in(:'form_first_name', :with => :'Harry')
     @session.click_button('awesome')
-    extract_results(@session)['first_name'].should == 'Harry'
+    expect(extract_results(@session)['first_name']).to eq('Harry')
   end
 
   it "casts to string if field has maxlength" do
     @session.fill_in(:'form_zipcode', :with => 1234567)
     @session.click_button('awesome')
-    extract_results(@session)['zipcode'].should == '12345'
+    expect(extract_results(@session)['zipcode']).to eq('12345')
   end
 
   context 'on a pre-populated textfield with a reformatting onchange', :requires => [:js] do
@@ -127,7 +127,7 @@ Capybara::SpecHelper.spec "#fill_in" do
       @session.fill_in('with_change_event', :with => 'some value')
       # click outside the field to trigger the change event
       @session.find(:css, 'body').click
-      @session.find(:css, '.change_event_triggered', :match => :one).should have_text 'some value'
+      expect(@session.find(:css, '.change_event_triggered', :match => :one)).to have_text 'some value'
     end
 
     it 'should trigger change when clearing field' do
@@ -135,7 +135,7 @@ Capybara::SpecHelper.spec "#fill_in" do
       @session.fill_in('with_change_event', :with => '')
       # click outside the field to trigger the change event
       @session.find(:css, 'body').click
-      @session.should have_selector(:css, '.change_event_triggered', :match => :one)
+      expect(@session).to have_selector(:css, '.change_event_triggered', :match => :one)
     end
   end
 
@@ -171,7 +171,7 @@ Capybara::SpecHelper.spec "#fill_in" do
     it "should accept partial matches when false" do
       @session.fill_in("Explanation", :with => "Dude", :exact => false)
       @session.click_button("awesome")
-      extract_results(@session)["name_explanation"].should == "Dude"
+      expect(extract_results(@session)["name_explanation"]).to eq("Dude")
     end
 
     it "should not accept partial matches when true" do
