@@ -4,13 +4,13 @@ Capybara::SpecHelper.spec '#has_table?' do
   end
 
   it "should be true if the table is on the page" do
-    @session.should have_table('Villain')
-    @session.should have_table('villain_table')
-    @session.should have_table(:'villain_table')
+    expect(@session).to have_table('Villain')
+    expect(@session).to have_table('villain_table')
+    expect(@session).to have_table(:'villain_table')
   end
 
   it "should be false if the table is not on the page" do
-    @session.should_not have_table('Monkey')
+    expect(@session).not_to have_table('Monkey')
   end
 end
 
@@ -20,11 +20,11 @@ Capybara::SpecHelper.spec '#has_no_table?' do
   end
 
   it "should be false if the table is on the page" do
-    @session.should_not have_no_table('Villain')
-    @session.should_not have_no_table('villain_table')
+    expect(@session).not_to have_no_table('Villain')
+    expect(@session).not_to have_no_table('villain_table')
   end
 
   it "should be true if the table is not on the page" do
-    @session.should have_no_table('Monkey')
+    expect(@session).to have_no_table('Monkey')
   end
 end
