@@ -1,6 +1,6 @@
 Capybara::SpecHelper.spec '#response_headers' do
   it "should return response headers", :requires => [:response_headers] do
     @session.visit('/with_simple_html')
-    @session.response_headers['Content-Type'].should =~ %r(text/html)
+    expect(@session.response_headers['Content-Type']).to match %r(text/html)
   end
 end
