@@ -5,33 +5,33 @@ Capybara::SpecHelper.spec '#within_frame', :requires => [:frames] do
 
   it "should find the div in frameOne" do
     @session.within_frame("frameOne") do
-      @session.find("//*[@id='divInFrameOne']").text.should eql 'This is the text of divInFrameOne'
+      expect(@session.find("//*[@id='divInFrameOne']").text).to eql 'This is the text of divInFrameOne'
     end
   end
   it "should find the div in FrameTwo" do
     @session.within_frame("frameTwo") do
-      @session.find("//*[@id='divInFrameTwo']").text.should eql 'This is the text of divInFrameTwo'
+      expect(@session.find("//*[@id='divInFrameTwo']").text).to eql 'This is the text of divInFrameTwo'
     end
   end
   it "should find the text div in the main window after finding text in frameOne" do
     @session.within_frame("frameOne") do
-      @session.find("//*[@id='divInFrameOne']").text.should eql 'This is the text of divInFrameOne'
+      expect(@session.find("//*[@id='divInFrameOne']").text).to eql 'This is the text of divInFrameOne'
     end
-    @session.find("//*[@id='divInMainWindow']").text.should eql 'This is the text for divInMainWindow'
+    expect(@session.find("//*[@id='divInMainWindow']").text).to eql 'This is the text for divInMainWindow'
   end
   it "should find the text div in the main window after finding text in frameTwo" do
     @session.within_frame("frameTwo") do
-      @session.find("//*[@id='divInFrameTwo']").text.should eql 'This is the text of divInFrameTwo'
+      expect(@session.find("//*[@id='divInFrameTwo']").text).to eql 'This is the text of divInFrameTwo'
     end
-    @session.find("//*[@id='divInMainWindow']").text.should eql 'This is the text for divInMainWindow'
+    expect(@session.find("//*[@id='divInMainWindow']").text).to eql 'This is the text for divInMainWindow'
   end
   it "should return the result of executing the block" do
-    @session.within_frame("frameOne") { "return value" }.should eql "return value"
+    expect(@session.within_frame("frameOne") { "return value" }).to eql "return value"
   end
   it "should find the div given Element" do
     element = @session.find(:id, 'frameOne')
     @session.within_frame element do
-      @session.find("//*[@id='divInFrameOne']").text.should eql 'This is the text of divInFrameOne'
+      expect(@session.find("//*[@id='divInFrameOne']").text).to eql 'This is the text of divInFrameOne'
     end
   end
   it "should find multiple nested frames" do
@@ -45,7 +45,7 @@ Capybara::SpecHelper.spec '#within_frame', :requires => [:frames] do
   it "should reset scope when changing frames" do
     @session.within(:css, '#divInMainWindow') do
       @session.within_frame 'parentFrame' do
-        @session.has_selector?(:css, "iframe#childFrame").should be_true
+        expect(@session.has_selector?(:css, "iframe#childFrame")).to be true
       end
     end
   end
