@@ -1,16 +1,24 @@
 require 'spec_helper'
 
-describe Capybara do
-
-  describe 'default_wait_time' do
+RSpec.describe Capybara do
+  describe 'default_max_wait_time' do
     after do
-      Capybara.default_wait_time = @previous_default_time
+      Capybara.default_max_wait_time = @previous_default_time
     end
 
     it "should be changeable" do
-      @previous_default_time = Capybara.default_wait_time
+      @previous_default_time = Capybara.default_max_wait_time
+      Capybara.default_max_wait_time = 5
+      expect(Capybara.default_max_wait_time).to eq(5)
+    end
+
+    it "should be accesible as the deprecated default_wait_time" do
+      expect_any_instance_of(Kernel).to receive(:warn).once.with('DEPRECATED: #default_wait_time= is deprecated, please use #default_max_wait_time= instead')
+      expect_any_instance_of(Kernel).to receive(:warn).once.with('DEPRECATED: #default_wait_time is deprecated, please use #default_max_wait_time instead')
+      @previous_default_time = Capybara.default_max_wait_time
       Capybara.default_wait_time = 5
-      Capybara.default_wait_time.should == 5
+      expect(Capybara.default_wait_time).to eq(5)
+      expect(Capybara.default_max_wait_time).to eq(5)
     end
   end
 
@@ -21,7 +29,7 @@ describe Capybara do
       end
       session = Capybara::Session.new(:schmoo, TestApp)
       session.visit('/')
-      session.body.should include("Hello world!")
+      expect(session.body).to include("Hello world!")
     end
   end
 
@@ -32,19 +40,19 @@ describe Capybara do
 
     it "should default to a proc that calls run_default_server" do
       mock_app = double('app')
-      Capybara.should_receive(:run_default_server).with(mock_app, 8000)
+      expect(Capybara).to receive(:run_default_server).with(mock_app, 8000)
       Capybara.server.call(mock_app, 8000)
     end
 
     it "should return a custom server proc" do
       server = lambda {|app, port|}
       Capybara.server(&server)
-      Capybara.server.should == server
+      expect(Capybara.server).to eq(server)
     end
   end
 end
 
-describe Capybara::Session do
+RSpec.describe Capybara::Session do
   context 'with non-existant driver' do
     it "should raise an error" do
       expect {
