@@ -1,8 +1,8 @@
 require 'spec_helper'
 
-describe Capybara::Selenium::Driver do
+RSpec.describe Capybara::Selenium::Driver do
   it "should exit with a zero exit status" do
     browser = Capybara::Selenium::Driver.new(TestApp).browser
-    true.should == true
+    expect(true).to eq(true)
   end
 end
